@@ -27,9 +27,11 @@ Base id of standard checkers (used in msg and report ids):
 09: design_analysis
 10: newstyle
 11: typecheck
-"""
+12: rpython
 
-__revision__ = "$Id: __init__.py,v 1.21 2005-11-21 23:08:11 syt Exp $"
+The raw_metrics checker has no number associated since it doesn't emit any
+messages nor reports. XXX not true, emit a 07 report !
+"""
 
 import tokenize
 from os import listdir
@@ -66,6 +68,7 @@ class BaseChecker(OptionsProviderMixIn, ASTWalker):
 
     options = ()
     priority = -9
+    enabled = True
     may_be_disabled = True
     name = None
     
@@ -85,16 +88,17 @@ class BaseChecker(OptionsProviderMixIn, ASTWalker):
 
     def is_enabled(self):
         """return true if the checker is enabled"""
-        opt = 'enable_' + self.name
-        return getattr(self.config, opt, True)
+        return self.enabled
 
-    def enable(self, enable):
+    def enable(self, enabled):
         """enable / disable this checker if true / false is given
 
         it false values has no effect if the checker can't be disabled
         """
-        if enable or self.may_be_disabled:
-            setattr(self.config, 'enable_' + self.name, enable)
+        if not enabled and not self.may_be_disabled:
+            raise Exception("can't disable %s checker" % self.name)
+        if enabled or self.may_be_disabled:
+            self.enabled = enabled
         
     def package_dir(self):
         """return the base directory for the analysed package"""
@@ -117,7 +121,7 @@ class BaseRawChecker(BaseChecker):
         
         the module's content is accessible via the stream object
         
-        stream must implements the readline method
+        stream must implement the readline method
         """
         self.process_tokens(tokenize.generate_tokens(stream.readline))
     
