@@ -28,7 +28,7 @@ import re
 # regex for class/function/variable/constant nane
 CLASS_NAME_RGX = re.compile('[A-Z_][a-zA-Z0-9]+$')
 MOD_NAME_RGX = re.compile('(([a-z_][a-z0-9_]*)|([A-Z][a-zA-Z0-9]+))$')
-CONST_NAME_RGX = re.compile('(([A-Z_][A-Z1-9_]*)|(__.*__))$')
+CONST_NAME_RGX = re.compile('(([A-Z_][A-Z0-9_]*)|(__.*__))$')
 COMP_VAR_RGX = re.compile('[A-Za-z_][A-Za-z0-9_]*$')
 DEFAULT_NAME_RGX = re.compile('[a-z_][a-z0-9_]{2,30}$')
 # do not require a doc string on system methods
@@ -105,13 +105,13 @@ MSGS = {
     'E0103': ('%r not properly in loop',
               'Used when break or continue keywords are used outside a loop.'),
 
-    'E0104': ('return outside function',
+    'E0104': ('Return outside function',
               'Used when a "return" statement is found outside a function or '
               'method.'),
-    'E0105': ('yield outside function',
+    'E0105': ('Yield outside function',
               'Used when a "yield" statement is found outside a function or '
               'method.'),
-    'E0106': ('return with argument inside generator',
+    'E0106': ('Return with argument inside generator',
               'Used when a "return" statement with an argument is found '
               'outside in a generator function or method (e.g. with some '
               '"yield" statements).'),
