@@ -1,4 +1,4 @@
-# Copyright (c) 2003-2006 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2003-2008 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -16,18 +16,19 @@
 """imports checkers for Python code
 """
 
-from logilab.common.graph import get_cycles
+from logilab.common.graph import get_cycles, DotBackend
 from logilab.common.modutils import is_standard_module, is_relative, \
      get_module_part
 from logilab.common.ureports import VerbatimText, Paragraph
 
 from logilab import astng
 
+from pylint.utils import expand_modules
 from pylint.interfaces import IASTNGChecker
 from pylint.checkers import BaseChecker, EmptyReport
 from pylint.checkers.utils import are_exclusive
 
-def get_first_import(context, name, base):
+def get_first_import(context, name, base, level=0):
     """return the node where [base.]<name> is imported or None if not found
     """
     for node in context.values():
@@ -35,7 +36,7 @@ def get_first_import(context, name, base):
             if name in [iname[0] for iname in node.names]:
                 return node
         if isinstance(node, astng.From):
-            if base == node.modname and \
+            if base == node.modname and level == node.level and \
                    name in [iname[0] for iname in node.names]:
                 return node
             
@@ -92,38 +93,25 @@ def repr_tree_defs(data, indent_str=None):
             lines.append(repr_tree_defs(sub, sub_indent_str))
     return '\n'.join(lines)
 
-def dot_node(modname):
-    """return the string representation for a dot node"""
-    return '"%s" [ label="%s" ];' % (modname, modname)
-
-def dot_edge(from_, to_):
-    """return the string representation for a dot edge between two nodes"""
-    return'"%s" -> "%s" [ ] ;' % (from_, to_)
-
-DOT_HEADERS = '''rankdir="LR" URL="." concentrate=false
-edge[fontsize="10" ]
-node[width="0" height="0" fontsize="12" fontcolor="black"]'''
 
 def dependencies_graph(filename, dep_info):
-    """write dependencies as defined in the dep_info dictionary as a dot
-    (graphviz) file
+    """write dependencies as a dot (graphviz) file 
     """
     done = {}
-    stream = open(filename, 'w')
-    print >> stream, "digraph g {"
-    print >> stream, DOT_HEADERS
+    printer = DotBackend(filename[:-4], rankdir = "LR")
+    printer.emit('URL="." node[shape="box"]')
     for modname, dependencies in dep_info.items():
         done[modname] = 1
-        print >> stream, dot_node(modname)
+        printer.emit_node(modname)
         for modname in dependencies:
             if not done.has_key(modname):
                 done[modname] = 1
-                print >> stream, dot_node(modname)
+                printer.emit_node(modname)
     for depmodname, dependencies in dep_info.items():
         for modname in dependencies:
-            print >> stream, dot_edge(modname, depmodname)
-    print >> stream,'}'
-    stream.close()
+            printer.emit_edge(modname, depmodname)
+    printer.generate(filename)
+
 
 def make_graph(filename, dep_info, sect, gtype):
     """generate a dependencies graph and add some information about it in the
@@ -234,6 +222,8 @@ given file (report R0402 must not be disabled)'}
     def visit_import(self, node):
         """triggered when an import statement is seen"""
         for name, _ in node.names:
+            if self._module_not_exists(node, name):
+                continue
             self._check_deprecated(node, name)
             relative = self._check_relative(node, name)
             self._imported_module(node, name, relative)
@@ -242,44 +232,62 @@ given file (report R0402 must not be disabled)'}
         
 
     def visit_from(self, node):
-        """triggered when an import statement is seen"""
+        """triggered when a from statement is seen"""
         basename = node.modname
+        if self._module_not_exists(node, basename):
+            return
         if basename == '__future__':
-            # check this is the first non docstring statement in the module
+            # check if this is the first non-docstring statement in the module
             prev = node.previous_sibling()
             if prev:
                 # consecutive future statements are possible
-                if not(isinstance(prev, astng.From)
+                if not (isinstance(prev, astng.From)
                        and prev.modname == '__future__'):
                     self.add_message('W0410', node=node)
         self._check_deprecated(node, basename)
-        relative = self._check_relative(node, basename)
+        level = node.level
+        if level > 0: # explicit relative import (leading dots)
+            relative = True
+        else:
+            relative = self._check_relative(node, basename)
         for name, _ in node.names:
             if name == '*':
                 self.add_message('W0401', args=basename, node=node)
                 continue
             # handle reimport
-            self._check_reimport(node, name, basename)
+            self._check_reimport(node, name, basename, level)
             # analyze dependencies
-            fullname = '%s.%s' % (basename, name)
-            if fullname.find('.') > -1:
-                try:
-                    # XXXFIXME: don't use get_module_part which doesn't take
-                    # care of package precedence
-                    fullname = get_module_part(fullname,
-                                               context_file=node.root().file)
-                except ImportError, ex:
-                    self.add_message('F0401', args=(fullname, ex), node=node)
-                    continue            
+            fullname = '.' * level + '%s.%s' % (basename, name)
+            fullname = get_module_part(fullname,context_file=node.root().file)
             self._imported_module(node, fullname, relative)
-        
+
+    def _module_not_exists(self, node, modname):
+        """check if module exists and possibly add message"""
+        result, errors = expand_modules([modname], [])
+        if not errors or is_relative(modname, node.root().file):
+            return False
+        error = errors[0]
+        if error["key"] == "F0001":
+            args = (error["mod"], error["ex"])
+            self.add_message("F0401", args=args, node=node)
+            return True
+        assert error["key"] == "F0003"
+        return False
+
     def _imported_module(self, node, mod_path, relative):
         """notify an imported module, used to analyze dependencies
         """
         context_name = node.root().name
         if relative:
-            mod_path = '%s.%s' % ('.'.join(context_name.split('.')[:-1]),
-                                  mod_path)
+            context_parts = context_name.split('.')
+            if mod_path.startswith('.'):
+                while mod_path.startswith('.'):
+                    mod_path = mod_path[1:]
+                    del context_parts[-1] # one level upwards
+                context_parts.append(mod_path)
+            else:
+                context_parts[-1] = mod_path
+            mod_path = '.'.join(context_parts)
         if context_name == mod_path:
             # module importing itself !
             self.add_message('W0406', node=node)
@@ -296,7 +304,6 @@ given file (report R0402 must not be disabled)'}
 
     def _check_relative(self, node, mod_path):
         """check relative import module"""
-        # check for relative import
         context_file = node.root().file
         relative = is_relative(mod_path, context_file)
         if relative:
@@ -311,11 +318,11 @@ given file (report R0402 must not be disabled)'}
                     or mod_path[len(mod_name)] == '.'):
                 self.add_message('W0402', node=node, args=mod_path)
     
-    def _check_reimport(self, node, name, basename=None):
+    def _check_reimport(self, node, name, basename=None, level=0):
         """check if the import is necessary (i.e. not already done)
         """
         frame = node.frame()
-        first = get_first_import(frame, name, basename)
+        first = get_first_import(frame, name, basename, level)
         if isinstance(first, (astng.Import, astng.From)) and first is not node \
                and not are_exclusive(first, node):
             self.add_message('W0404', node=node, args=(name, first.lineno))
