@@ -16,8 +16,6 @@
 """check for new / old style related problems
 """
 
-import sys
-
 from logilab import astng
 
 from pylint.interfaces import IASTNGChecker
@@ -31,17 +29,10 @@ MSGS = {
     'E1003': ('Bad first argument %r given to super class',
               'Used when another argument than the current class is given as \
               first argument of the super builtin.'),
-    'E1010': ('Raising a new style class',
-              'Used when a new style class is raised since it\'s not \
-              possible with python < 2.5.'),
-    
     'W1001': ('Use of "property" on an old style class',
               'Used when PyLint detect the use of the builtin "property" \
               on an old style class while this is relying on new style \
               classes features'),
-    'W1010': ('Exception doesn\'t inherit from standard "Exception" class',
-              'Used when a custom exception class is raised but doesn\'t \
-              inherit from the builtin "Exception" class.'),
     }
 
 
@@ -50,7 +41,6 @@ class NewStyleConflictChecker(BaseChecker):
     other new/old styles conflicts problems                                    
     * use of property, __slots__, super                                        
     * "super" usage                                                            
-    * raising a new style class as exception                                   
     """
     
     __implements__ = (IASTNGChecker,)
@@ -81,26 +71,7 @@ class NewStyleConflictChecker(BaseChecker):
             name = node.node.name
             if name == 'property':
                 self.add_message('W1001', node=node)
-        
-    def visit_raise(self, node):
-        """check for raising new style class
-        """
-        # ignore empty raise
-        if node.expr1 is None:
-            return
-        if not isinstance(node.expr1, (astng.Const, astng.Mod)):
-            try:
-                name = node.expr1.nodes_of_class(astng.Name).next()
-                value = name.infer().next()
-            except (StopIteration, astng.ResolveError):
-                pass
-            else:
-                if isinstance(value, astng.Class):
-                    if value.newstyle and sys.version_info < (2, 5):
-                        self.add_message('E1010', node=node)
-                    elif not inherit_from_std_ex(value):
-                        self.add_message('W1010', node=node)
-                        
+
     def visit_function(self, node):
         """check use of super"""
         # ignore actual functions or method within a new style class
@@ -129,20 +100,8 @@ class NewStyleConflictChecker(BaseChecker):
                     if klass is not supcls:
                         supcls = getattr(supcls, 'name', supcls)
                         self.add_message('E1003', node=node, args=supcls)
-                            
-                    
-                        
-def inherit_from_std_ex(node):
-    """return true if the given class node is subclass of
-    exceptions.Exception
-    """
-    if node.name == 'Exception' and node.root().name == 'exceptions':
-        return True
-    for parent in node.ancestors(recurs=False):
-        if inherit_from_std_ex(parent):
-            return True
-    return False
-        
+
+
 def register(linter):
     """required method to auto register this checker """
     linter.register_checker(NewStyleConflictChecker(linter))
