@@ -1,5 +1,5 @@
-# Copyright (c) 2003-2007 Sylvain Thenault (thenault@gmail.com).
-# Copyright (c) 2003-2007 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2003-2008 Sylvain Thenault (thenault@gmail.com).
+# Copyright (c) 2003-2008 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -34,11 +34,9 @@ import sys
 import os
 import re
 import tokenize
-from os.path import dirname, basename, splitext, exists, isdir, join, normpath
 
 from logilab.common.configuration import OptionsManagerMixIn, check_csv
-from logilab.common.modutils import modpath_from_file, get_module_files, \
-     file_from_modpath, load_module_from_name
+from logilab.common.modutils import load_module_from_name
 from logilab.common.interface import implements
 from logilab.common.textutils import get_csv
 from logilab.common.fileutils import norm_open
@@ -49,7 +47,7 @@ from logilab.astng import ASTNGManager
 from logilab.astng.__pkginfo__ import version as astng_version
 
 from pylint.utils import UnknownMessage, MessagesHandlerMixIn, \
-     ReportsHandlerMixIn, MSG_TYPES, sort_checkers
+     ReportsHandlerMixIn, MSG_TYPES, sort_checkers, expand_modules
 from pylint.interfaces import ILinter, IRawChecker, IASTNGChecker
 from pylint.checkers import BaseRawChecker, EmptyReport, \
      table_lines_from_stats
@@ -72,11 +70,11 @@ REPORTER_OPT_MAP = {'text': TextReporter,
     
 MSGS = {
     'F0001': ('%s',
-              'Used when an error occured preventing the analyzing of a \
+              'Used when an error occured preventing the analysis of a \
               module (unable to find it for instance).'),
     'F0002': ('%s: %s',
               'Used when an unexpected error occured while building the ASTNG \
-              representation. This is usually accomopagned by a traceback. \
+              representation. This is usually accompanied by a traceback. \
               Please report such errors !'),
     'F0003': ('ignored builtin module %s',
               'Used to indicate that the user asked to analyze a builtin module\
@@ -91,13 +89,13 @@ MSGS = {
     
     'I0010': ('Unable to consider inline option %r',
               'Used when an inline option is either badly formatted or can\'t \
-be used inside modules.'),
+              be used inside modules.'),
     
     'I0011': ('Locally disabling %s',
-              'Used when an inline option disable a message or a messages \
+              'Used when an inline option disables a message or a messages \
               category.'),
     'I0012': ('Locally enabling %s',
-              'Used when an inline option enable a message or a messages \
+              'Used when an inline option enables a message or a messages \
               category.'),
     'I0013': ('Ignoring entire file',
               'Used to inform that the file will not be checked'),
@@ -116,7 +114,7 @@ class PyLinter(OptionsManagerMixIn, MessagesHandlerMixIn, ReportsHandlerMixIn,
                BaseRawChecker):
     """lint Python modules using external checkers.                            
                                                                                
-    This is the main checker controling the other ones and the reports         
+    This is the main checker controlling the other ones and the reports         
     generation. It is itself both a raw checker and an astng checker in order  
     to:                                                                        
     * handle message activation / deactivation at the module level             
@@ -167,7 +165,7 @@ python modules names) to load, usually to register additional checkers.'}),
                  'choices': ('text', 'parseable', 'msvs', 'colorized', 'html'),
                  'short': 'f',
                  'group': 'Reports',
-                 'help' : 'set the output format. Available formats are text,\
+                 'help' : 'Set the output format. Available formats are text,\
                  parseable, colorized, msvs (visual studio) and html'}),
 
                ('include-ids',
@@ -196,7 +194,7 @@ Reports (if any) will be written in a file name "pylint_global.[txt|html]".'}),
                  'default': '10.0 - ((float(5 * error + warning + refactor + \
 convention) / statement) * 10)', 
                  'help' : 'Python expression which should return a note less \
-than 10 (10 is the highest note).You have access to the variables errors \
+than 10 (10 is the highest note). You have access to the variables errors \
 warning, statement which respectivly contain the number of errors / warnings\
  messages and the total number of statements analyzed. This is used by the \
  global evaluation report (R0004).'}),
@@ -426,18 +424,18 @@ This is used by the global evaluation report (R0004).'}),
         # recurse on children (depth first)
         for child in node.getChildNodes():
             self.collect_block_lines(child, msg_state)            
+        first = node.source_line()
+        last = node.last_source_line()
         for msgid, lines in msg_state.items():
-            #if msg in self._module_msgs_state:
-            #    continue
             for lineno, state in lines.items():
-                first = node.source_line()
-                last = node.last_source_line()
-                if lineno >= first and lineno <= last:
+                if first <= lineno <= last:
                     # set state for all lines for this block
                     first, last = node.block_range(lineno)
-                    for line in xrange(first, last+1):
+                    for line in xrange(first, last+1):                        
                         # do not override existing entries
                         if not line in self._module_msgs_state.get(msgid, ()):
+                            if line in lines: # state change in the same block
+                                state = lines[line] 
                             try:
                                 self._module_msgs_state[msgid][line] = state
                             except KeyError:
@@ -454,93 +452,47 @@ This is used by the global evaluation report (R0004).'}),
         self.reporter.include_ids = self.config.include_ids
         if not isinstance(files_or_modules, (list, tuple)):
             files_or_modules = (files_or_modules,)
-        filemods = self.expand_files(files_or_modules)
         checkers = sort_checkers(self._checkers.values())
-        rev_checkers = checkers[:]
-        rev_checkers.reverse()
         # notify global begin
         for checker in checkers:
             checker.open()
-        # prebuild ast for all modules to check
-        for descr in filemods[:]:
+        # build ast and check modules or packages
+        for descr in self.expand_files(files_or_modules):
             modname, filepath = descr['name'], descr['path']
             self.set_current_module(modname, filepath)
             # get the module representation
-            try:
-                astng = self.get_astng(filepath, modname)
-            except SyntaxError, ex:
-                self.add_message('E0001', line=ex.lineno, args=ex.msg)
-                astng = None
+            astng = self.get_astng(filepath, modname)
             if astng is None:
-                filemods.remove(descr)
                 continue
-            descr['astng'] = astng
-        # check modules or packages        
-        for descr in filemods:
-            modname, filepath = descr['name'], descr['path']
-            astng = descr['astng']
             self.base_name = descr['basename']
             self.base_file = descr['basepath']
             if self.config.files_output:
                 reportfile = 'pylint_%s.%s' % (modname, self.reporter.extension)
                 self.reporter.set_output(open(reportfile, 'w'))
-            self.set_current_module(modname, filepath)
             self._ignore_file = False
             # fix the current file (if the source file was not available or
-            # if its actually a c extension
+            # if it's actually a c extension)
             self.current_file = astng.file
             self.check_astng_module(astng, checkers)
         # notify global end
         self.set_current_module('')
-        for checker in rev_checkers:
+        checkers.reverse()
+        for checker in  checkers:
             checker.close()
 
-    def expand_files(self, files_or_modules):
-        """take a list of files/modules/packages and return the list of tuple
-        (file, module name) which have to be actually checked
+    def expand_files(self, modules):
+        """get modules and errors from a list of modules and handle errors
         """
-        result = []
-        for something in files_or_modules:
-            if exists(something):
-                # this is a file or a directory
-                try:
-                    modname = '.'.join(modpath_from_file(something))
-                except ImportError:
-                    modname = splitext(basename(something))[0]
-                if isdir(something):
-                    filepath = join(something, '__init__.py')
-                else:
-                    filepath = something
-            else:
-                # suppose it's a module or package
-                modname = something
-                try:
-                    filepath = file_from_modpath(modname.split('.'))
-                    if filepath is None:
-                        self.set_current_module(modname)
-                        self.add_message('F0003', args=modname)
-                        continue
-                except ImportError, ex:
-                    #if __debug__:
-                    #    import traceback
-                    #    traceback.print_exc()
-                    self.set_current_module(modname)
-                    msg = str(ex).replace(os.getcwd() + os.sep, '')
-                    self.add_message('F0001', args=msg)
-                    continue
-            filepath = normpath(filepath)
-            result.append( {'path': filepath, 'name': modname,
-                            'basepath': filepath, 'basename': modname} )
-            if not modname.endswith('.__init__') and '__init__.py' in filepath:
-                for subfilepath in get_module_files(dirname(filepath),
-                                                    self.config.black_list):
-                    if filepath == subfilepath:
-                        continue
-                    submodname = '.'.join(modpath_from_file(subfilepath))
-                    result.append( {'path': subfilepath, 'name': submodname,
-                                    'basepath': filepath, 'basename': modname} )
+        result, errors = expand_modules(modules, self.config.black_list)
+        for error in errors:
+            message = modname = error["mod"]
+            key = error["key"]
+            self.set_current_module(modname)
+            if key == "F0001":
+                message = str(error["ex"]).replace(os.getcwd() + os.sep, '')
+            self.add_message(key, args=message)
         return result
-        
+
     def set_current_module(self, modname, filepath=None):
         """set the name of the currently analyzed module and
         init statistics for it
@@ -592,7 +544,6 @@ This is used by the global evaluation report (R0004).'}),
             orig_state = self._module_msgs_state.copy()
             self._module_msgs_state = {}
             self.collect_block_lines(astng, orig_state)
-
             for checker in checkers:
                 if implements(checker, IRawChecker) and checker is not self:
                     stream.seek(0)
@@ -611,7 +562,7 @@ This is used by the global evaluation report (R0004).'}),
             _reversed_checkers.reverse()
         if astng.is_statement():
             self.stats['statement'] += 1
-        # generate events for this node on each checkers
+        # generate events for this node on each checker
         for checker in checkers:
             checker.visit(astng)
         # recurse on children
@@ -779,7 +730,7 @@ class Run:
 group are mutually exclusive.'),
         )
     
-    def __init__(self, args, reporter=None, quiet=0):
+    def __init__(self, args, reporter=None):
         self._rcfile = None
         self._plugins = []
         preprocess_options(args, {
@@ -845,7 +796,6 @@ are done by default'''}),
 
             ), option_groups=self.option_groups,
                reporter=reporter, pylintrc=self._rcfile)
-        linter.quiet = quiet
         # register standard checkers
         from pylint import checkers
         checkers.initialize(linter)
@@ -860,7 +810,7 @@ There are 5 kind of message types :
     * (C) convention, for programming standard violation                       
     * (R) refactor, for bad code smell                                         
     * (W) warning, for python specific problems                                
-    * (E) error, for much probably bugs in the code                            
+    * (E) error, for probable bugs in the code                            
     * (F) fatal, if an error occured which prevented pylint from doing further \
 processing.     
         ''')
