@@ -20,6 +20,6 @@ class MyClass:
         self.var = "correct"
 
 if __name__ == '__main__':
-    obj = MyClass()
-    obj.met()
+    OBJ = MyClass()
+    OBJ.met()
 
