@@ -65,7 +65,7 @@ class RunTC(TestCase):
         sys.sterr = StringIO()
         try:
             try:
-                Run(args, quiet=1)
+                Run(args)
             except SystemExit, ex:
                 self.assertEquals(ex.code, exit_code)
             else:
@@ -93,8 +93,8 @@ class PyLinterTC(TestCase):
         
     def test_message_help(self):
         msg = self.linter.get_message_help('F0001', checkerref=True)
-        expected = ':F0001:\n  Used when an error occured preventing the analyzing of a module (unable to\n  find it for instance). This message belongs to the master checker.'
-        self.assertEquals(' '.join(msg.splitlines()), ' '.join(expected.splitlines()))
+        expected = ':F0001:\n  Used when an error occured preventing the analysis of a module (unable to find\n  it for instance). This message belongs to the master checker.'
+        self.assertTextEqual(msg, expected)
         self.assertRaises(UnknownMessage, self.linter.get_message_help, 'YB12')
         
     def test_enable_message(self):
