@@ -1,5 +1,5 @@
-# Copyright (c) 2003-2006 Sylvain Thenault (thenault@gmail.com).
-# Copyright (c) 2003-2006 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2003-2008 Sylvain Thenault (thenault@gmail.com).
+# Copyright (c) 2003-2008 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -44,15 +44,11 @@ MSG_TYPES = {
 MSG_CATEGORIES = MSG_TYPES.keys()
 
 
-def sort_checkers(checkers, enabled_only=True):
+def sort_checkers(checkers):
     """return a list of enabled checker sorted by priority"""
-    if enabled_only:
-        checkers = [(-checker.priority, checker) for checker in checkers
-                    if checker.is_enabled()]
-    else:
-        checkers = [(-checker.priority, checker) for checker in checkers]
-    checkers.sort()
-    return [item[1] for item in checkers]
+    checkers = [checker for checker in checkers if checker.is_enabled()]
+    checkers.sort(lambda x, y: cmp(-x.priority, -y.priority) )
+    return checkers
 
 def sort_msgs(msg_ids):
     """sort message identifiers according to their category first"""
@@ -384,4 +380,50 @@ class ReportsHandlerMixIn:
             assert not self.stats.has_key(key)
             self.stats[key] = value
         return self.stats
-    
+
+###     ###     - - - -   import utils    - - - -     ###     ###
+
+from os.path import dirname, basename, splitext, exists, isdir, join, normpath
+from logilab.common.modutils import modpath_from_file, get_module_files, \
+                                    file_from_modpath, is_relative
+
+def expand_modules(files_or_modules, black_list):
+    """take a list of files/modules/packages and return the list of tuple
+    (file, module name) which have to be actually checked
+    """
+    result = []
+    errors = []
+    for something in files_or_modules:
+        if exists(something):
+            # this is a file or a directory
+            try:
+                modname = '.'.join(modpath_from_file(something))
+            except ImportError:
+                modname = splitext(basename(something))[0]
+            if isdir(something):
+                filepath = join(something, '__init__.py')
+            else:
+                filepath = something
+        else:
+            # suppose it's a module or package
+            modname = something
+            try:
+                filepath = file_from_modpath(modname.split('.'))
+                if filepath is None:
+                    errors.append( {'key' : 'F0003', 'mod': modname} )
+                    continue
+            except ImportError, ex:
+                    errors.append( {'key': 'F0001', 'mod': modname, 'ex': ex} )
+                    continue
+        filepath = normpath(filepath)
+        result.append( {'path': filepath, 'name': modname,
+                        'basepath': filepath, 'basename': modname} )
+        if not (modname.endswith('.__init__') or modname == '__init__') \
+                and '__init__.py' in filepath:
+            for subfilepath in get_module_files(dirname(filepath), black_list):
+                if filepath == subfilepath:
+                    continue
+                submodname = '.'.join(modpath_from_file(subfilepath))
+                result.append( {'path': subfilepath, 'name': submodname,
+                                'basepath': filepath, 'basename': modname} )
+    return result, errors
